@@ -37,13 +37,13 @@ def _format(
     if fig.layout.yaxis.title.text is None:
         warnings.warn("Y-axis label not specified!")
 
-    if fig.layout.title.text:
+    if fig.layout.title.text is not None:
         new_title = " ".join(fig.layout.title.text.split("_")).capitalize()
         fig.update_layout(title=new_title)
-    if fig.layout.xaxis.title.text:
+    if fig.layout.xaxis.title.text is not None:
         new_xlabel = " ".join(fig.layout.xaxis.title.text.split("_")).capitalize()
         fig.update_layout(xaxis_title=new_xlabel)
-    if fig.layout.yaxis.title.text:
+    if fig.layout.yaxis.title.text is not None:
         new_ylabel = " ".join(fig.layout.yaxis.title.text.split("_")).capitalize()
         fig.update_layout(yaxis_title=new_ylabel)
 
